---
title: <span class="badge object-type-scalar"></span> IOOpsPerSecond
---
# <span class="badge object-type-scalar"></span> IOOpsPerSecond

Throughput: I/O ops/sec (iops)

## Definition

```python
# Throughput: I/O ops/sec (iops)
IOOpsPerSecond: typing.Literal["iops"] = "iops"
```
